@@ -1,5 +1,5 @@
 import requests
-from sent.methods.messages import SendMessage
+from sent.methods.messages import SendMessage, copyMessage, forwardMessage, editMessageText, deleteMessageText
 from sent.methods.authentication import GetMe, LogOut, Close
 
 class Telegram:
@@ -7,6 +7,10 @@ class Telegram:
         self.token = token
         self.url = f"https://api.telegram.org/bot{token}/"
         self.send_message = SendMessage(token).send_message
+        self.delete_message_text = deleteMessageText(token).delete_message_text
+        self.copy_message = copyMessage(token).copy_message
+        self.forward_message = forwardMessage(token).forward_message
+        self.edit_message_text = editMessageText(token).edit_message_text
         self.get_me = GetMe(token).get_me
         self.log_out = LogOut(token).log_out
         self.close = Close(token).close
