@@ -1,11 +1,8 @@
 from sent.telegram import Telegram
 
-print('Enter your YOUR_TOKEN:')
-token = input()
-print('Enter your CHAT_ID:')
-chatid = input()
+chatid = 1288398723
 
-bot = Telegram(token)
+bot = Telegram('5912234148:AAFSJ-6reLRM3zqqYRtFxmZiAXgqW29BwL0')
 bot.send_message(chatid, 'Hello, World!')
 
 response = bot.get_me()
